@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 import argparse
-from fast_eval import util
+from fast_eval.util import FastEval
 def main():
     print('coucou')
     parser = argparse.ArgumentParser()
